#
# spec file for package ghc-postgresql-simple
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name postgresql-simple
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.6.5.1
Release:        1.8
Summary:        Mid-Level PostgreSQL client library
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Patch0:         https://github.com/haskellari/postgresql-simple/pull/110.patch#/dont-depend-on-obsolete-bytestring-builder.patch
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-Only-devel
BuildRequires:  ghc-Only-prof
BuildRequires:  ghc-aeson-devel
BuildRequires:  ghc-aeson-prof
BuildRequires:  ghc-attoparsec-devel
BuildRequires:  ghc-attoparsec-prof
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-case-insensitive-devel
BuildRequires:  ghc-case-insensitive-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-hashable-devel
BuildRequires:  ghc-hashable-prof
BuildRequires:  ghc-postgresql-libpq-devel
BuildRequires:  ghc-postgresql-libpq-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-scientific-devel
BuildRequires:  ghc-scientific-prof
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-template-haskell-prof
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
BuildRequires:  ghc-time-compat-devel
BuildRequires:  ghc-time-compat-prof
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-transformers-prof
BuildRequires:  ghc-uuid-types-devel
BuildRequires:  ghc-uuid-types-prof
BuildRequires:  ghc-vector-devel
BuildRequires:  ghc-vector-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-HUnit-prof
BuildRequires:  ghc-base16-bytestring-devel
BuildRequires:  ghc-base16-bytestring-prof
BuildRequires:  ghc-cryptohash-md5-devel
BuildRequires:  ghc-cryptohash-md5-prof
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-filepath-prof
BuildRequires:  ghc-inspection-testing-devel
BuildRequires:  ghc-inspection-testing-prof
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-golden-devel
BuildRequires:  ghc-tasty-golden-prof
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-tasty-hunit-prof
BuildRequires:  ghc-tasty-prof
%endif

%description
Mid-Level PostgreSQL client library, forked from mysql-simple.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%setup -q -n %{pkg_name}-%{version}
%patch0 -p1

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGES.md CONTRIBUTORS

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Sun Jul  9 2023 Peter Simons <psimons@suse.com>
- Update postgresql-simple to version 0.6.5.1.
  [#]## Version 0.6.5.1 (2023-07-09)
  * Support `aeson-2.2.0.0`
* Tue Apr 11 2023 Peter Simons <psimons@suse.com>
- Update postgresql-simple to version 0.6.5 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
- Apply "dont-depend-on-obsolete-bytestring-builder.patch" to avoid
  depending on the obsolete bytestring-builder package.
* Sun Oct 30 2022 Peter Simons <psimons@suse.com>
- Update postgresql-simple to version 0.6.5.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/postgresql-simple-0.6.5/src/CHANGES.md
* Mon Jun 20 2022 Peter Simons <psimons@suse.com>
- Update postgresql-simple to version 0.6.4 revision 8.
  Upstream has revised the Cabal build instructions on Hackage.
* Sat Jan  1 2022 Peter Simons <psimons@suse.com>
- Update postgresql-simple to version 0.6.4 revision 6.
  Upstream has revised the Cabal build instructions on Hackage.
* Sat Nov 20 2021 psimons@suse.com
- Update postgresql-simple to version 0.6.4 revision 5.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Nov 15 2021 psimons@suse.com
- Update postgresql-simple to version 0.6.4 revision 4.
  Upstream has revised the Cabal build instructions on Hackage.
* Sun Oct 10 2021 psimons@suse.com
- Update postgresql-simple to version 0.6.4 revision 3.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Mar 23 2021 psimons@suse.com
- Update postgresql-simple to version 0.6.4 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Sun Feb 21 2021 psimons@suse.com
- Update postgresql-simple to version 0.6.4 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Fri Jan  8 2021 psimons@suse.com
- Update postgresql-simple to version 0.6.4.
  [#]## Version 0.6.4 (2021-01-06)
  * Add foldCopyData helper function
    Thanks to Sebastián Estrella for the implementation
    https://github.com/haskellari/postgresql-simple/pull/56
  * Implement support for postgresql 'interval' type
    Thanks to Andre Marques Lee for the implementation
    https://github.com/haskellari/postgresql-simple/pull/60
  * Depend on `time-compat` to provide uniform `time` related interface.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Sun Nov 15 2020 psimons@suse.com
- Update postgresql-simple to version 0.6.3.
  [#]## Version 0.6.3 (2020-11-15)
  * Add `fromFieldJSONByteString`
    Thanks to tomjaguarpaw for the implementation
    https://github.com/haskellari/postgresql-simple/pull/47
  * Add `attoFieldParser`
    Thanks to Victor Nawothnig for the implementation
    https://github.com/haskellari/postgresql-simple/pull/45
  * Add `Identity` and `Const` instance
    Thanks to Cary Robbins for the implementation
    https://github.com/haskellari/postgresql-simple/pull/46
  * Add `withTransactionModeRetry'`, a variant of `withTransactionModeRetry`
    for all exception types.
    Thanks to Elliot Cameron for the implementation
    https://github.com/haskellari/postgresql-simple/pull/42
  * Fix spurious aborts when retrying transactions
    Thanks to Elliot Cameron for the implementation
    https://github.com/haskellari/postgresql-simple/pull/34
  * Add `Database.PostgreSQL.Simple.Newtypes` module
    with `Aeson` newtype.
    https://github.com/haskellari/postgresql-simple/pull/55
* Mon Aug 31 2020 psimons@suse.com
- Update postgresql-simple to version 0.6.2 revision 4.
  Upstream has revised the Cabal build instructions on Hackage.
* Wed Aug 19 2020 Michel Normand <normand@linux.vnet.ibm.com>
- Add _constraints with 6GB min disk space for ppc64/ppc64le
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Fri May 29 2020 psimons@suse.com
- Add postgresql-simple at version 0.6.2.
